# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ImageUploadResponse(UniversalBaseModel):
    """
    Response schema for image upload.
    """

    success: bool = pydantic.Field()
    """
    Whether the upload was successful
    """

    message: str = pydantic.Field()
    """
    Success message
    """

    urls: typing.Dict[str, str] = pydantic.Field()
    """
    Image URLs for different sizes (thumbnail, medium, full)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
