# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ComposioSyncResponse(UniversalBaseModel):
    """
    Response schema for connector sync endpoint.
    """

    job_id: str
    status: str
    tools_synced: int
    tools_created: int
    tools_updated: int
    tools_unchanged: typing.Optional[int] = None
    sync_mode: typing.Optional[str] = None
    message: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
