# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UserProfileResponse(UniversalBaseModel):
    """
    Schema for user profile response with detailed information.
    """

    id: str = pydantic.Field()
    """
    User ID with usr_ prefix
    """

    email: str
    username: typing.Optional[str] = None
    full_name: typing.Optional[str] = None
    first_name: typing.Optional[str] = None
    last_name: typing.Optional[str] = None
    birthday: typing.Optional[dt.date] = None
    profile_image: typing.Optional[str] = None
    timezone: typing.Optional[str] = None
    country_id: typing.Optional[str] = None
    post_code: typing.Optional[str] = None
    gender: typing.Optional[str] = None
    is_active: bool
    last_verified: typing.Optional[dt.datetime] = None
    last_login: typing.Optional[dt.datetime] = None
    created_at: dt.datetime
    updated_at: dt.datetime
    current_organization_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
