# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class KnowledgeSliceResponse(UniversalBaseModel):
    """
    Schema for knowledge slice response.
    """

    id: str
    name: str
    description: typing.Optional[str] = None
    type: str
    is_composite: bool
    owner_type: str
    owner_id: str
    status: str
    member_slice_ids: typing.Optional[typing.List[str]] = None
    store_count: int
    organization_id: str
    created_by: typing.Optional[str] = None
    created_at: dt.datetime
    updated_at: dt.datetime
    archived_at: typing.Optional[dt.datetime] = None
    archived_by: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
