# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SpeakerAnalysis(UniversalBaseModel):
    """
    Speaker diarization configuration.
    """

    diarization_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enable speaker identification
    """

    speakers_expected_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Expected number of speakers (1-10)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
