# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .create_flowplate_key_response import CreateFlowplateKeyResponse


class RefreshFlowplateKeyResponse(UniversalBaseModel):
    """
    Response schema for Flowplate key refresh (includes new raw key).
    """

    success: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the refresh was successful
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Action result message
    """

    new_key: CreateFlowplateKeyResponse = pydantic.Field()
    """
    The new key details (old key is now invalid)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
