# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class LoginResponse(UniversalBaseModel):
    """
    Response schema for login endpoint.
    """

    success: bool
    message: str
    email_key: str
    email: str
    requires_verification: bool
    next_step: str
    type: str = pydantic.Field()
    """
    Verification type: 'login', 'registration', or 'password_reset'
    """

    user: typing.Dict[str, typing.Any]
    device_info: typing.Optional[typing.Dict[str, typing.Any]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
