# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class LoginVerificationResponse(UniversalBaseModel):
    """
    Response schema for login verification endpoint.
    """

    refresh_token: str = pydantic.Field()
    """
    Refresh token
    """

    access_token: str
    token_type: str
    expires_in: int
    device_id: typing.Optional[str] = None
    user: typing.Dict[str, typing.Any]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
